==> default-gateway-0.8.0.tgz: package/linux.js <==
const net = require("net");
const {exec} = require("child_process");

const getDefaultNetwork = (command, callback) => {
  exec(command, function(error, stdout, stderr) {
    if (error !== null) { return callback(error); }
    if (stderr.trim() !== "") { return callback(new Error(stderr.trim())); }
    if (stdout.trim() === "") { return callback(null, {}); }
    const data = {};
    stdout = stdout.trim();
    for (const line of Array.from(stdout.split("\n"))) {
      const [defaultGateway, defaultInterface] = Array.from(line.split(" "));
      if ((defaultGateway === null) || (defaultInterface === null)) {
        return callback(new Error(`parse error: ${stdout}`));
      }
      if (!net.isIP(defaultGateway)) {
        return callback(new Error(`parse error: ${stdout}`));
      }
      data[defaultInterface] = data[defaultInterface] || [];
      const family = (() => {
        switch (net.isIP(defaultGateway)) {
        case 4: return "IPv4";
        case 6: return "IPv6";
        }
      })();
      if ((family === null)) {
        return callback(new Error(`invalid address: ${stdout}`));
      }
      data[defaultInterface].push({
        family,
        address: defaultGateway
      });
    }
    return callback(null, data);
  });
};

const getDefaultNetworkByInet4 = callback => {
  getDefaultNetwork("netstat -rn -A inet | awk '$4~/UG/ {print $2,$8;}'",
    (error, data) => callback(error, data));
};

const getDefaultNetworkByInet6 = callback => {
  getDefaultNetwork("netstat -rn -A inet6 | awk '$4~/UG/ {print $2,$7;}'",
    (error, data) => callback(error, data));
};

module.exports = callback => {
  getDefaultNetworkByInet4((_, data4) =>
    getDefaultNetworkByInet6(function(_, data6) {
      const result = {};
      for (const data of [data4, data6]) {
        Object.keys(data).forEach(iface => {
          const adapters = data[iface];
          result[iface] = result[iface] || [];
          result[iface].push(...Array.from(adapters || []));
        });
      }
      // collect() does not return errors
      return callback(null, result);
    })
  );
};

==> default-gateway-0.8.4.tgz: package/linux.js <==
const net = require("net");
const {exec} = require("child_process");

const getDefaultNetwork = (command, callback) => {
  exec(command, function(error, stdout, stderr) {
    if (error !== null) { return callback(error); }
    if (stderr.trim() !== "") { return callback(new Error(stderr.trim())); }
    if (stdout.trim() === "") { return callback(null, {}); }
    const data = {};
    stdout = stdout.trim();
    for (const line of Array.from(stdout.split("\n"))) {
      const [defaultGateway, defaultInterface] = Array.from(line.split(" "));
      if ((defaultGateway === null) || (defaultInterface === null)) {
        return callback(new Error(`parse error: ${stdout}`));
      }
      if (!net.isIP(defaultGateway)) {
        return callback(new Error(`parse error: ${stdout}`));
      }
      data[defaultInterface] = data[defaultInterface] || [];
      const family = (() => {
        switch (net.isIP(defaultGateway)) {
        case 4: return "IPv4";
        case 6: return "IPv6";
        }
      })();
      if ((family === null)) {
        return callback(new Error(`invalid address: ${stdout}`));
      }
      data[defaultInterface].push({
        family,
        address: defaultGateway
      });
    }
    return callback(null, data);
  });
};

const getDefaultNetworkByInet4 = callback => {
  getDefaultNetwork("netstat -rn -A inet | awk '$4~/UG/ {print $2,$8;}'",
    (error, data) => callback(error, data));
};

const getDefaultNetworkByInet6 = callback => {
  getDefaultNetwork("netstat -rn -A inet6 | awk '$4~/UG/ {print $2,$7;}'",
    (error, data) => callback(error, data));
};

module.exports = callback => {
  getDefaultNetworkByInet4((_, data4 = []) =>
    getDefaultNetworkByInet6(function(_, data6 = []) {
      const result = {};
      for (const data of [data4, data6]) {
        Object.keys(data).forEach(iface => {
          const adapters = data[iface];
          result[iface] = result[iface] || [];
          result[iface].push(...Array.from(adapters || []));
        });
      }
      // collect() does not return errors
      return callback(null, result);
    })
  );
};
